@@ -1,7 +1,7 @@
 ###############################################################################
 ## Tucan Project
 ##
-## Copyright (C) 2008-2009 Fran Lupion crak@tucaneando.com
+## Copyright (C) 2008-2010 Fran Lupion crak@tucaneando.com
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,53 +18,48 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ###############################################################################
 
-import sys
-import subprocess
-import os.path
-import pickle
+import urllib
 import logging
 logger = logging.getLogger(__name__)
 
-from captcha import CaptchaForm
 from check_links import CheckLinks
 
 from core.download_plugin import DownloadPlugin
 from core.url_open import URLOpen
-from core.slots import Slots
+from core.tesseract import Tesseract
 
 import core.cons as cons
 
 WAIT = 45
 
-class AnonymousDownload(DownloadPlugin, Slots):
+CAPTCHACODE = "captchacode"
+MEGAVAR = "megavar"
+
+class AnonymousDownload(DownloadPlugin):
 	""""""
-	def __init__(self):
+	def link_parser(self, url, wait_func, content_range=None):
 		""""""
-		Slots.__init__(self, 1)
-		DownloadPlugin.__init__(self)
-
-	def add(self, path, link, file_name):
-		""""""
-		if self.get_slot():
-			parser = CaptchaForm(link)
-			if parser.link:
-				return self.start(path, parser.link, file_name, WAIT, None, self.post_wait)
-
-	def post_wait(self, link):
-		"""Must return handle"""
+		link = None
+		wait = WAIT
 		try:
-			handle = URLOpen().open(link)
+			for line in URLOpen().open(url).readlines():
+				if 'id="downloadlink"' in line:
+					link = line.split('href="')[1].split('"')[0]
+				if "count=" in line:
+					wait = int(line.split("=")[1].split(";")[0])
+			if not link:
+				return
+			elif not wait_func(WAIT):
+				return
 		except Exception, e:
-			self.add_wait()
-			self.return_slot()
-			logger.warning("Limit Exceded.")
+			logger.exception("%s: %s" % (url, e))
 		else:
-			return handle
-
-	def delete(self, file_name):
-		""""""
-		if self.stop(file_name):
-			logger.info("Stopped %s: %s" % (file_name, self.return_slot()))
+			try:
+				handle = URLOpen().open(link, None, content_range)
+			except:
+				return self.set_limit_exceeded()
+			else:
+				return handle
 
 	def check_links(self, url):
 		""""""
