@@ -1,7 +1,7 @@
 ###############################################################################
 ## Tucan Project
 ##
-## Copyright (C) 2008-2009 Fran Lupion crak@tucaneando.com
+## Copyright (C) 2008-2010 Fran Lupion crak@tucaneando.com
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -32,7 +32,3 @@ class PremiumCookie:
 		opener.open("http://www.megaupload.com/?c=login", urllib.urlencode({"login": "1", "redir": "1", "username": user, "password": password}))
 		if len(cookie) > 0:
 			return cookie
-
-if __name__ == "__main__":
-	c = PremiumCookie()
-	print c.get_cookie("","")
\ No newline at end of file
