@@ -1,7 +1,7 @@
 ###############################################################################
 ## Tucan Project
 ##
-## Copyright (C) 2008-2009 Fran Lupion crak@tucaneando.com
+## Copyright (C) 2008-2010 Fran Lupion crak@tucaneando.com
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,42 +18,43 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ###############################################################################
 
-import urllib2
 import logging
 logger = logging.getLogger(__name__)
 
 from premium_cookie import PremiumCookie
-from premium_parser import PremiumParser
 from check_links import CheckLinks
 
 from core.accounts import Accounts
-from core.service_config import SECTION_PREMIUM_DOWNLOAD, ServiceConfig
 from core.download_plugin import DownloadPlugin
+from core.url_open import URLOpen
 
 class PremiumDownload(DownloadPlugin, Accounts):
 	""""""
-	def __init__(self, config):
+	def __init__(self, config, section):
 		""""""
-		Accounts.__init__(self, config, SECTION_PREMIUM_DOWNLOAD, PremiumCookie())
-		DownloadPlugin.__init__(self)
+		Accounts.__init__(self, config, section, PremiumCookie())
+		DownloadPlugin.__init__(self, config, section)
 
-	def add(self, path, link, file_name):
+	def link_parser(self, url, wait_func, content_range=None):
 		""""""
-		cookie = self.get_cookie()
-		if cookie:
-			parser = PremiumParser(link, cookie)
-			link = parser.get_url()
-			if link:
-				return self.start(path, link, file_name, None, cookie)
-
-	def delete(self, file_name):
-		""""""
-		logger.warning("Stopped %s: %s" % (file_name, self.stop(file_name)))
+		found = False
+		try:
+			cookie = self.get_cookie()
+			if not wait_func():
+				return
+			opener = URLOpen(cookie)
+			handler = opener.open(url, None, content_range)
+			if not wait_func():
+				return
+			if "text/html" in handler.info()["Content-Type"]:
+				for line in handler:
+					if 'class="down_ad_butt1">' in line:
+						return opener.open(line.split('href="')[1].split('"')[0], None, content_range)
+			else:
+				return handler
+		except Exception, e:
+			logger.exception("%s: %s" % (url, e))
 
 	def check_links(self, url):
 		""""""
 		return CheckLinks().check(url)
-
-if __name__ == "__main__":
-	p = PremiumDownload(ServiceConfig("/home/crak/.tucan/plugins/megaupload/"))
-	p.check_links("http://www.megaupload.com/es/?d=RDAJ2PYH")
