@@ -1,7 +1,7 @@
 ###############################################################################
 ## Tucan Project
 ##
-## Copyright (C) 2008-2009 Fran Lupion crak@tucaneando.com
+## Copyright (C) 2008-2010 Fran Lupion crak@tucaneando.com
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -22,68 +22,42 @@ import urllib
 import logging
 logger = logging.getLogger(__name__)
 
-from HTMLParser import HTMLParser
-
 from check_links import CheckLinks
 
 from core.download_plugin import DownloadPlugin
 from core.url_open import URLOpen
 from core.slots import Slots
 
-class FormParser(HTMLParser):
-	""""""
-	def __init__(self, url):
-		""""""
-		HTMLParser.__init__(self)
-		self.form_action = None
-		self.url = None
-		self.wait = None
-		try:
-			self.feed(URLOpen().open(url).read())
-			self.close()
-			form = {"dl.start": "Free", "":"Free user"}
-			self.data = urllib.urlencode(form)
-			if self.form_action:
-				for line in URLOpen().open(self.form_action, self.data).readlines():
-					if not self.url:
-						self.feed(line)
-					else:
-						if "var c=" in line:
-							self.wait = int(line.split("var c=")[1].split(";")[0])
-		except Exception, e:
-			logger.exception("%s: %s" % (url, e))
+#MAX_SIZE = 209796096
+MAX_SIZE = None
 
-	def handle_starttag(self, tag, attrs):
-		""""""
-		if tag == "form":
-			if attrs[0][1] == "ff":
-				self.form_action = attrs[1][1]
-			elif attrs[0][1] == "dlf":
-				self.url = attrs[1][1]
+API_URL = "/cgi-bin/rsapi.cgi"
 
 class AnonymousDownload(DownloadPlugin, Slots):
 	""""""
-	def __init__(self):
+	def link_parser(self, url, wait_func, content_range=None):
 		""""""
-		Slots.__init__(self, 1)
-		DownloadPlugin.__init__(self)
+		link = None
+		wait = 0
+		try:
+			tmp = url.split("/")
+			opener = URLOpen()
+			form =  urllib.urlencode([("sub", "download_v1"), ("fileid", tmp[4]), ("filename", tmp[5])])
+			for line in opener.open("http://api.rapidshare.com%s" % API_URL, form, content_range):
+				if "DL:" in line:
+					tmp = line.split("DL:")[1].split(",")
+					link = "http://%s%s" % (tmp[0], API_URL)
+					form =  "%s&%s" % (form, urllib.urlencode([("dlauth", tmp[1])]))
+					wait = int(tmp[2])
+			if not wait_func(wait):
+				return
+			elif link:
+				return URLOpen().open(link, form, content_range)
+			else:
+				return self.set_limit_exceeded()
+		except Exception, e:
+			logger.exception("%s: %s" % (url, e))
 
 	def check_links(self, url):
 		""""""
-		return CheckLinks().check(url)
-
-	def add(self, path, link, file_name):
-		""""""
-		if self.get_slot():
-			parser = FormParser(link)
-			if parser.url:
-				return self.start(path, parser.url, file_name, parser.wait)
-			else:
-				self.add_wait()
-				self.return_slot()
-				logger.warning("Limit Exceded.")
-
-	def delete(self, file_name):
-		""""""
-		if self.stop(file_name):
-			logger.warning("Stopped %s: %s" % (file_name, self.return_slot()))
+		return CheckLinks().check(url, MAX_SIZE)
