@@ -1,7 +1,7 @@
 ###############################################################################
 ## Tucan Project
 ##
-## Copyright (C) 2008-2009 Fran Lupion crak@tucaneando.com
+## Copyright (C) 2008-2010 Fran Lupion crak@tucaneando.com
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -22,71 +22,45 @@ import urllib
 import logging
 logger = logging.getLogger(__name__)
 
-from HTMLParser import HTMLParser
-
 from premium_cookie import PremiumCookie
 from check_links import CheckLinks
 
-from core.service_config import SECTION_PREMIUM_DOWNLOAD
-from core.download_plugin import DownloadPlugin
 from core.accounts import Accounts
+from core.download_plugin import DownloadPlugin
 from core.url_open import URLOpen
 
-import core.cons as cons
-
-class FormParser(HTMLParser):
-	""""""
-	def __init__(self, url, cookie):
-		""""""
-		HTMLParser.__init__(self)
-		self.form_action = None
-		self.url = None
-		self.close()
-		try:
-			opener = URLOpen(cookie)
-			handler = opener.open(url)
-			if "text/html" in handler.info()["Content-Type"]:
-				self.feed(handler.read())
-				if self.form_action:
-					for line in opener.open(self.form_action, urllib.urlencode({"dl.start": "PREMIUM", "":"Premium user"})).readlines():
-						self.feed(line)
-			else:
-				self.url = url
-		except Exception, e:
-			print e
-			logger.error("%s: %s" % (url, e))
-
-	def handle_starttag(self, tag, attrs):
-		""""""
-		if tag == "form":
-			if len(attrs) == 2:
-				self.form_action = attrs[0][1]
-			elif attrs[0][1] == "dlf":
-				self.url = attrs[1][1]
+API_URL = "/cgi-bin/rsapi.cgi"
 
 class PremiumDownload(DownloadPlugin, Accounts):
 	""""""
-	def __init__(self, config):
+	def __init__(self, config, section):
 		""""""
-		Accounts.__init__(self, config, SECTION_PREMIUM_DOWNLOAD, PremiumCookie())
-		DownloadPlugin.__init__(self)
+		Accounts.__init__(self, config, section, PremiumCookie())
+		DownloadPlugin.__init__(self, config, section)
+
+	def link_parser(self, url, wait_func, content_range=None):
+		""""""
+		try:
+			cookie = self.get_cookie()
+			if not wait_func():
+				return
+			opener = URLOpen(cookie)
+			handler = opener.open(url, None, content_range)
+			if not wait_func():
+				return
+			if "text/html" in handler.info()["Content-Type"]:
+				cookie_value = cookie._cookies[".rapidshare.com"]["/"]["enc"].value
+				tmp = url.split("/")
+				form =  urllib.urlencode([("sub", "download_v1"), ("cookie", cookie_value), ("fileid", tmp[4]), ("filename", tmp[5])])
+				for line in opener.open("http://api.rapidshare.com%s" % API_URL, form, content_range):
+					if "DL:" in line:
+						tmp_url = "http://%s%s" % (line.split("DL:")[1].split(",")[0], API_URL)
+						return opener.open(tmp_url, form, content_range)
+			else:
+				return handler
+		except Exception, e:
+			logger.exception("%s: %s" % (url, e))
 
 	def check_links(self, url):
 		""""""
 		return CheckLinks().check(url)
-
-	def add(self, path, link, file_name):
-		""""""
-		cookie = self.get_cookie()
-		if cookie:
-			f = FormParser(link, cookie)
-			if f.url:
-				return self.start(path, f.url, file_name, None, cookie)
-
-	def delete(self, file_name):
-		""""""
-		logger.warning("Stopped %s: %s" % (file_name, self.stop(file_name)))
-
-if __name__ == "__main__":
-	c = PremiumCookie()
-	p = FormParser("", c.get_cookie("",""))
